@@ -19,7 +19,7 @@
 namespace fst {
 namespace script {
 
-bool GetCDRewriteDirection(const std::string &str, CDRewriteDirection *rd) {
+bool GetCDRewriteDirection(std::string_view str, CDRewriteDirection *rd) {
   if (str == "ltr") {
     *rd = LEFT_TO_RIGHT;
   } else if (str == "rtl") {
@@ -32,7 +32,7 @@ bool GetCDRewriteDirection(const std::string &str, CDRewriteDirection *rd) {
   return true;
 }
 
-bool GetCDRewriteMode(const std::string &str, CDRewriteMode *rm) {
+bool GetCDRewriteMode(std::string_view str, CDRewriteMode *rm) {
   if (str == "obl") {
     *rm = OBLIGATORY;
   } else if (str == "opt") {
